#! /usr/bin/python

from argparse import ArgumentParser
from mpl_toolkits.mplot3d import axes3d
from matplotlib.pyplot import *
from matplotlib.cm import *

from cobra.io.sbml import create_cobra_model_from_sbml_file
from cobra.io.sbml import write_cobra_model_to_sbml_file
from cobra import Metabolite, Reaction

from numpy import *

parser = ArgumentParser(description="add enterobactin reaction to e.coli model")
parser.add_argument("in_model", help="base SBML model")
parser.add_argument("opt_start", help="start value of the range", type=float)
parser.add_argument("opt_end", help="end value of the range", type=float)
parser.add_argument("opt_step", help="step value of the range", type=float)

parser.add_argument("chor_start", help="start value of the range", type=float)
parser.add_argument("chor_end", help="end value of the range", type=float)
parser.add_argument("chor_step", help="step value of the range", type=float)

args = parser.parse_args()

model = create_cobra_model_from_sbml_file(args.in_model)

assert 'ENTSYNTH' in model.reactions
assert 'ENTOUT' in model.reactions

#add chorismate input flux
C00251 = model.metabolites.get_by_id('chor_c')

CHOR = Reaction('in_flux')
CHOR.name = "chorismate input flux"
CHOR.id = "CHORIN"
CHOR.lower_bound = 0
CHOR.reversibility = 0
CHOR.objective_coefficient = 0.0
CHOR.add_metabolites({C00251: 1.0})

model.add_reaction(CHOR)

assert args.chor_start < args.chor_end
assert args.opt_start < args.opt_end
assert args.opt_end <= 1


biom = model.reactions.get_by_id("BiomassEcoli")
entout_react = model.reactions.get_by_id("ENTOUT")

x = arange(args.chor_start, args.chor_end, args.chor_step)
y = arange(args.opt_start, args.opt_end, args.opt_step)

growth = zeros((len(y), len(x)))
entout = zeros((len(y), len(x)))
chor_flux = zeros((len(y), len(x)))

i = 0
while i < len(x):
    CHOR.upper_bound = x[i]

    j = 0
    while j < len(y):
        entout_react.objective_coefficient = y[j]
        biom = 1 - y[j]

        model.optimize(solver="glpk")

        entout[j,i] = model.solution.x_dict["ENTOUT"]
        chor_flux[j,i] = model.solution.x_dict["CHORM"]

        j += 1
    i += 1

X,Y = meshgrid(x,y)

fig = figure()
ax = fig.add_subplot(111, projection='3d')
surf = ax.plot_surface(X,Y,entout, cmap=coolwarm, rstride=1, cstride=1)

xlabel("CHORIN (mmol/gDW/h)")
ylabel("i")
ax.zaxis.set_label_text("ENTOUT (mmol/gDW/h)")

show()
