#! /usr/bin/python

from argparse import ArgumentParser

from matplotlib.pyplot import *
from cobra.io.sbml import create_cobra_model_from_sbml_file
from cobra.io.sbml import write_cobra_model_to_sbml_file
from cobra import Metabolite, Reaction

parser = ArgumentParser(description="add enterobactin reaction to e.coli model")
parser.add_argument("in_model", help="base SBML model")
parser.add_argument("start", help="start value of the range", type=float)
parser.add_argument("end", help="end value of the range", type=float)
parser.add_argument("step", help="step value of the range", type=float)

args = parser.parse_args()

model = create_cobra_model_from_sbml_file(args.in_model)

assert 'ENTSYNTH' in model.reactions
assert 'ENTOUT' in model.reactions

x = []
growth = []
ichorsi_flux = []
ichort_flux = []
chorm_flux = []
ans_flux = []
adcs_flux = []
chrpl_flux = []
entout_flux = []
succinyl_flux = []

i = args.start
assert args.start < args.end
assert args.end <= 1

biom = model.reactions.get_by_id("BiomassEcoli")
entout_react = model.reactions.get_by_id("ENTOUT")

while i < args.end:
    entout_react.objective_coefficient = i
    biom.objective_coefficient = 1 - i

    model.optimize(solver="glpk")

    x.append(i)
    growth.append(model.solution.f)
    ichorsi_flux.append(model.solution.x_dict["ICHORSi"])
    ichort_flux.append(model.solution.x_dict["ICHORT"])
    ans_flux.append(model.solution.x_dict["ANS"])
    chorm_flux.append(model.solution.x_dict["CHORM"])
    adcs_flux.append(model.solution.x_dict["ADCS"])
    chrpl_flux.append(model.solution.x_dict["CHRPL"])
    entout_flux.append(model.solution.x_dict["ENTOUT"])
    succinyl_flux.append(model.solution.x_dict["SHCHCS2"])
    i += args.step

plot(x, growth, 'o')
plot(x, entout_flux, 'o')
plot(x, ichorsi_flux)
plot(x, ichort_flux)
plot(x, chorm_flux, 'x')
plot(x, ans_flux, 'x')
plot(x, adcs_flux, 'x')
plot(x, chrpl_flux, 'x')

plot(x, succinyl_flux, 'x')

legend(["f", "ENTOUT",
        "Isochorismate synthase", "Isochorismatase",
        "Chorismate mutase",
        "Anthranilate synthase", "Deoxychorismate synthase",
        "Chorismate pyruvate lyase", "Succynil synthase"], loc=2)

ylabel("Flux (mmol/gDW/h)")
xlabel("i")

show()
