#! /usr/bin/python

from argparse import ArgumentParser
from matplotlib.pyplot import *

parser = ArgumentParser(description="add chorsimate quantities to ecoli model")

parser.add_argument("in_model", help="base SBML model")

args = parser.parse_args()

from numpy import arange

from cobra.io.sbml import create_cobra_model_from_sbml_file
from cobra.io.sbml import write_cobra_model_to_sbml_file
from cobra import Metabolite, Reaction

model = create_cobra_model_from_sbml_file(args.in_model)

x = []
obj_funct = []
chorm_flux = []


assert "CHORM" in model.reactions

CHORM = model.reactions.get_by_id("CHORM")

CHORM.upper_bound = 1
bound = CHORM.upper_bound

while bound >= 0:
    CHORM.upper_bound = bound
    model.optimize(solver="glpk")

    x.append(bound)
    obj_funct.append(model.solution.f)
    chorm_flux.append(model.solution.x_dict["ADCS"])

    bound -= 0.01

plot(x, obj_funct, 'x')
plot(x, chorm_flux)

xlabel("Deoxychorismate synthase upper bound(mmol/gDW/h)")
ylabel("Fluxes(mmol/gDW/h)")

legend(["Growth rate", "Deoxychorismate synthase"])
show()
